ari jay comet : blog | Sharing my life experiences. Interacting with technology.
Description: Sharing my life experiences. Interacting with technology.

Skip to content

## TESTED: Smart Home Automation – Comparing Apple HomeKit vs Samsung SmartThings Hub vs Wink Connected Home Hub vs INSTEON Hub Pro vs Amazon Echo vs Belkin WeMo

Shopping for smart home automation products can feel a bit like having lunch at a buffet. You can be easily overwhelmed by too many options to pick from, feeling unsure about what will taste good together. But unlike a fixed-price all-you-can-eat buffet, these smart home devices can get really expensive, really fast, so choosing the right ones is quite important. In this article we’ve taken on the task of taste-testing all these delicious pieces of technology for you, to provide you a curated review of what works, and what doesn’t. Check out the BEST HOME AUTOMATION PLATFORMS as we compare Apple HomeKit vs Samsung SmartThings, vs Wink Connected Home Hub vs Insteon Hub Pro vs Amazon Echo vs Belkin WeMo, and much, much more!

Continue reading TESTED: Smart Home Automation – Comparing Apple HomeKit vs Samsung SmartThings Hub vs Wink Connected Home Hub vs INSTEON Hub Pro vs Amazon Echo vs Belkin WeMo

## TESTED: An EPIC Comparison of Smart Light Bulbs — Philips Hue versus Belkin WeMo versus LIFX versus GE Link versus TCP Connected versus Misfit Bolt

Epic battle time! Are you thinking of dipping your toes into home automation this 2015 holiday season? Smart home lighting is typically the first step people take by replacing a few bulbs in their homes. But with more and more options available the decision has become increasingly more difficult. Whether you want a color bulb, or a basic white bulb, there are plenty of reasons to skip certain brands over the other. Keep reading to decide which bulbs to buy as we compare the Philips Hue versus Belkin WeMo versus LIFX versus GE Link versus TCP Connected versus Misfit Bolt smart light bulbs.

Continue reading TESTED: An EPIC Comparison of Smart Light Bulbs — Philips Hue versus Belkin WeMo versus LIFX versus GE Link versus TCP Connected versus Misfit Bolt

## Logitech Circle versus Withings Home versus Arlo Wireless – Camera Comparison

Arriving late to a crowded market, Logitech recently released their Logi Circle Portable Camera just in time for the 2015 holiday shopping season. They’re grabbing up prime end-cap space at retailers around the globe, hoping to make an impact in the home security camera realm. Our testing found this device has certain features remniscent of the offerings by both Arlo & Withings. Let’s see why that is, and how it compares to those devices and others.

Continue reading Logitech Circle versus Withings Home versus Arlo Wireless – Camera Comparison

## REVIEW: iRobot Roomba 980 Vacuum Cleaning Robot

Not since Rosie the maid/housekeeper on the Jetsons has there been a cleaning robot that excites me, until now. Earlier this year iRobot released their latest Robot Vacuum, and though their devices are not quite as charismatic as Rosie the XB-500 model in the Jetson family’s possession, they are the closest we’ll get to living in Orbit City right now. Let’s boot up the iRobot Roomba 980 Vacuum Cleaning Robot, and explore!

Continue reading REVIEW: iRobot Roomba 980 Vacuum Cleaning Robot

## QUICK LOOK: Arlo Smart Home Security Camera System (Indoor/Outdoor)

In recent history I’ve spent time testing & reviewing various WiFi cameras for home security. All of those devices I’ve blogged about before required a nearby power outlet to operate. In this post we’re shifting gears and looking at an option that is entirely wireless: the 100% Wire-Free Arlo Smart Home Security Camera System.

Continue reading QUICK LOOK: Arlo Smart Home Security Camera System (Indoor/Outdoor)

## COMPARISON: First Alert One Link Wi-Fi Smoke and Carbon Monoxide Detector versus Nest Protect 2nd Gen Smoke + Carbon Monoxide Alarm

When the Nest Protect 2nd generation device was revealed in the summer of 2015 it was improving upon an already great device. With no real competition to speak of I didn’t bother taking photos of my purchase, because there wasn’t really anything to compare it to for blog comparison purposes. But now that the HomeKit-enabled First Alert DC10-500 One Link Wi-Fi Smoke and Carbon Monoxide Detector has arrived, let’s see how it stacks up against the Nest Protect 2nd Gen Smoke and Carbon Monoxide Alarm.

Continue reading COMPARISON: First Alert One Link Wi-Fi Smoke and Carbon Monoxide Detector versus Nest Protect 2nd Gen Smoke + Carbon Monoxide Alarm

Follow

### Follow “ari jay comet : blog”

Get every new post delivered to your Inbox.

Join 641 other followers

Build a website with WordPress.com
Add your thoughts here... (optional) Post to
Cancel